@@ -245,11 +245,11 @@ def hours_per_TA(csv_rows):
   event_index = SIGNUP_SHEET_HEADER.index("Event")
 
   for row in csv_rows:
-    time = (arrow.get(row[end_index], "YYYY-MM-DD HH:mm") - \
-      arrow.get(row[start_index], "YYYY-MM-DD HH:mm"))
+    start_date = arrow.get(row[start_index], "YYYY-MM-DD HH:mm")
+    time = arrow.get(row[end_index], "YYYY-MM-DD HH:mm") - start_date
 
     time = round_time(time)
-    time = add_prep_time(time, row[event_index])
+    time = add_prep_time(time, row[event_index], start_date)
 
     booked, _ = get_booked_TAs_from_csv(row)
 
@@ -290,11 +290,11 @@ def max_hours(csv_rows):
   max_hours = datetime.timedelta()
 
   for row in csv_rows:
-    time = (arrow.get(row[end_index], "YYYY-MM-DD HH:mm") - \
-      arrow.get(row[start_index], "YYYY-MM-DD HH:mm"))
+    start_date = arrow.get(row[start_index], "YYYY-MM-DD HH:mm")
+    time = arrow.get(row[end_index], "YYYY-MM-DD HH:mm") - start_date
 
     time = round_time(time)
-    time = add_prep_time(time, row[event_index])
+    time = add_prep_time(time, row[event_index], start_date)
 
     max_num_TAs = int(row[needed_TAs_index])
 
@@ -325,6 +325,16 @@ def hours_per_event(csv_rows):
       event_hours[row[event_index]] = time
 
   return event_hours
+def time_for_event(event, amanuensis=False):
+  """
+  Input: an event of type ics.event.Event and an optional bool amanuensis 
+  specifying whether the computation is for an amanuensis or not.
+
+  Output: Returns a datetime.timedelta corresponding to the time including prep 
+  time for the event.
+  """
+  return add_prep_time(
+    round_time(event.end-event.begin), event.name, event.begin, amanuensis)
 def round_time(time):
   """
   Input: a datetime.timedelta object time.
@@ -346,20 +356,48 @@ def round_time(time):
     return datetime.timedelta(seconds=full_hours+2*QUARTER)
 
   return datetime.timedelta(seconds=full_hours)
-def add_prep_time(time, event_type):
+def add_prep_time(time, event_type,
+  date=datetime.date.today(), amanuensis=False):
   """
-  Input: a datetime.timedelta object time,
-    a string containing the title of the event.
+  Input:
+  - a datetime.timedelta object time,
+  - a string containing the title of the event,
+  - an optional date (datetime or arrow object) indicating the date of the 
+    event. If no date is given, today's date is assumed, meaning the latest 
+    prep-time policy will be used.
+  - an optional bool indicating amanuensis employment or hourly.
 
   Output: the time object rounded according to KTH rules.
   """
-  if "laboration" in event_type or "Laboration" in event_type:
-    time *= 1.33
-  elif "Övning" in event_type:
-    time *= 2
+  if date > arrow.Arrow(2023, 1, 1) or \
+    (date > arrow.Arrow(2022, 10, 1) and not amanuensis):
+    if check_substrings(
+          ["laboration", "seminarium", "redovisning"],
+          event_type.casefold()):
+      time *= 1.5
+    elif "övning" in event_type.casefold():
+      time *= 2
+  else:
+    if check_substrings(
+          ["laboration", "seminarium", "redovisning"],
+          event_type.casefold()):
+      time *= 1.33
+    elif "övning" in event_type.casefold():
+      time *= 2
 
   return time
-def compute_amanuensis_data(csv_rows, low_percentage=0.1, min_days=25):
+
+def check_substrings(substrings, string):
+  """
+  Check if any of the substrings (list) is a substring of string.
+  Return bool.
+  """
+  for substring in substrings:
+    if substring in string:
+      return True
+
+  return False
+def compute_amanuensis_data(csv_rows, low_percentage=0.05, min_days=25):
   """
   Input:
     - csv_rows, the CSV rows as output from csv.reader.
